# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from patch_api.configuration import Configuration


class CreateEthereumEstimateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "timestamp": "str",
        "gas_used": "int",
        "transaction_value_eth_gwei": "int",
        "project_id": "str",
        "create_order": "bool",
    }

    attribute_map = {
        "timestamp": "timestamp",
        "gas_used": "gas_used",
        "transaction_value_eth_gwei": "transaction_value_eth_gwei",
        "project_id": "project_id",
        "create_order": "create_order",
    }

    def __init__(
        self,
        timestamp=None,
        gas_used=None,
        transaction_value_eth_gwei=None,
        project_id=None,
        create_order=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """CreateEthereumEstimateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._gas_used = None
        self._transaction_value_eth_gwei = None
        self._project_id = None
        self._create_order = None
        self.discriminator = None

        self.timestamp = timestamp
        self.gas_used = gas_used
        self.transaction_value_eth_gwei = transaction_value_eth_gwei
        self.project_id = project_id
        self.create_order = create_order

    @property
    def timestamp(self):
        """Gets the timestamp of this CreateEthereumEstimateRequest.  # noqa: E501


        :return: The timestamp of this CreateEthereumEstimateRequest.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this CreateEthereumEstimateRequest.


        :param timestamp: The timestamp of this CreateEthereumEstimateRequest.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def gas_used(self):
        """Gets the gas_used of this CreateEthereumEstimateRequest.  # noqa: E501


        :return: The gas_used of this CreateEthereumEstimateRequest.  # noqa: E501
        :rtype: int
        """
        return self._gas_used

    @gas_used.setter
    def gas_used(self, gas_used):
        """Sets the gas_used of this CreateEthereumEstimateRequest.


        :param gas_used: The gas_used of this CreateEthereumEstimateRequest.  # noqa: E501
        :type: int
        """

        self._gas_used = gas_used

    @property
    def transaction_value_eth_gwei(self):
        """Gets the transaction_value_eth_gwei of this CreateEthereumEstimateRequest.  # noqa: E501


        :return: The transaction_value_eth_gwei of this CreateEthereumEstimateRequest.  # noqa: E501
        :rtype: int
        """
        return self._transaction_value_eth_gwei

    @transaction_value_eth_gwei.setter
    def transaction_value_eth_gwei(self, transaction_value_eth_gwei):
        """Sets the transaction_value_eth_gwei of this CreateEthereumEstimateRequest.


        :param transaction_value_eth_gwei: The transaction_value_eth_gwei of this CreateEthereumEstimateRequest.  # noqa: E501
        :type: int
        """

        self._transaction_value_eth_gwei = transaction_value_eth_gwei

    @property
    def project_id(self):
        """Gets the project_id of this CreateEthereumEstimateRequest.  # noqa: E501


        :return: The project_id of this CreateEthereumEstimateRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this CreateEthereumEstimateRequest.


        :param project_id: The project_id of this CreateEthereumEstimateRequest.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def create_order(self):
        """Gets the create_order of this CreateEthereumEstimateRequest.  # noqa: E501


        :return: The create_order of this CreateEthereumEstimateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_order

    @create_order.setter
    def create_order(self, create_order):
        """Sets the create_order of this CreateEthereumEstimateRequest.


        :param create_order: The create_order of this CreateEthereumEstimateRequest.  # noqa: E501
        :type: bool
        """

        self._create_order = create_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateEthereumEstimateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateEthereumEstimateRequest):
            return True

        return self.to_dict() != other.to_dict()
